@@ -7,7 +7,6 @@
 // See https://doc.rust-lang.org/rustc/lints/listing/allowed-by-default.html
 #![deny(missing_docs)]
 #![deny(missing_debug_implementations)]
-#![deny(unreachable_pub)]
 #![forbid(unused_must_use)]
 #![deny(unsafe_code)]
 #![cfg_attr(feature = "dox", feature(doc_cfg))]
@@ -24,6 +23,9 @@ pub use ostree::gio::glib;
 /// to a string to output to a terminal or logs.
 type Result<T> = anyhow::Result<T>;
 
+// Import global functions.
+mod globals;
+
 pub mod cli;
 pub mod container;
 pub mod container_utils;
@@ -34,7 +36,7 @@ pub mod refescape;
 pub mod tar;
 pub mod tokio_util;
 
-mod cmdext;
+pub(crate) mod commit;
 pub(crate) mod objgv;
 /// Prelude, intended for glob import.
 pub mod prelude {
@@ -43,4 +45,4 @@ pub mod prelude {
 }
 
 #[cfg(feature = "internal-testing-api")]
-mod integrationtest;
+pub mod integrationtest;
